# ListUserMetadataResponse

Response object for user org, app preferences
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**user_metadata** | [**list[UserMetadata]**](UserMetadata.md) | The matching UserOrgAppPreferences objects | 
**limit** | **int** | Limit on the number of rows in the response | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


